# bech32m

[![CI](https://github.com/ods/bech32m/actions/workflows/ci.yml/badge.svg)](https://github.com/ods/bech32m/actions/workflows/ci.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/bech32m.svg)](https://pypi.org/project/bech32m)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/bech32m.svg)](https://pypi.org/project/bech32m)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install bech32m
```

## License

`bech32m` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
